/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "language.h"
#include "assert/assert.h"

language_t LANGUAGE;

void languageInit(void) {
  LANGUAGE.current = LANGUAGE_EN;
}

const char_t * languageGet(const char_t *key) {
  assertNotNull(key, "Key cannot be NULL");
  assertTrue(LANGUAGE.current < LANGUAGE_COUNT, "Invalid language index");

  int16_t keyIndex = -1;
  for(uint16_t i = 0; i < LANGUAGE_COUNT; i++) {
    if(strcmp(LANGUAGE_KEYS[LANGUAGE.current][i], key) != 0) {
      continue;
    }
    keyIndex = i;
    break;
  }
  assertTrue(keyIndex != -1, "Key not found in language");
  return LANGUAGE_VALUES[LANGUAGE.current][keyIndex];
}

uint16_t langaugeGetLength(const char_t *key) {
  assertNotNull(key, "Key cannot be NULL");
  assertTrue(LANGUAGE.current < LANGUAGE_COUNT, "Invalid language index");

  int16_t keyIndex = -1;
  for(uint16_t i = 0; i < LANGUAGE_COUNT; i++) {
    if(strcmp(LANGUAGE_KEYS[LANGUAGE.current][i], key) != 0) {
      continue;
    }
    keyIndex = i;
    break;
  }
  assertTrue(keyIndex != -1, "Key not found in language");
  return strlen(LANGUAGE_VALUES[LANGUAGE.current][keyIndex]);
}