/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "locale/language/languages.h"

typedef struct {
  uint8_t current;
} language_t;

extern language_t LANGUAGE;

/**
 * Initializes the language system.
 * 
 * This function sets up the language system, loading the default language
 * and preparing any necessary resources for language handling.
 */
void languageInit(void);

/**
 * Gets a language string by its key.
 * 
 * @param key The key for the language string.
 * @return The language string associated with the key.
 */
const char_t * languageGet(const char_t *key);

/**
 * Gets the length of a language string by its key.
 * 
 * @param key The key for the language string.
 * @return The length of the language string associated with the key.
 */
uint16_t langaugeGetLength(const char_t *key);